summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--cli/src/main.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/cli/src/main.rs b/cli/src/main.rs
index 69bac940..64108a06 100644
--- a/cli/src/main.rs
+++ b/cli/src/main.rs
@@ -214,9 +214,9 @@ fn compile(command: CompileCommand) -> StrResult<()> {
let mut watcher = RecommendedWatcher::new(tx, notify::Config::default())
.map_err(|_| "failed to watch directory")?;
// Watch this directory recursively.
watcher
- .watch(Path::new("."), RecursiveMode::Recursive)
+ .watch(&world.root, RecursiveMode::Recursive)
.map_err(|_| "failed to watch directory")?;
// Handle events.
@@ -214,9 +214,9 @@ fn compile(command: CompileCommand) -> StrResult<()> {
let mut watcher = RecommendedWatcher::new(tx, notify::Config::default())
.map_err(|_| "failed to watch directory")?;
- // Watch this directory recursively.
+ // Watch root directory recursively.
watcher